@@ -6,6 +6,9 @@
 /* Define to enable sanity checking on memory allocation and casting */
 #undef DEBUG_ALLOC
 
+/* Define to enable tracing */
+#undef DEBUG_TRACE
+
 /* Define if zlib should be used */
 #undef WITH_ZLIB
 
@@ -31,7 +34,10 @@
 #undef SHUTDOWN_WORKS_WITH_UNIX_SOCKETS
 
 /* Define if the compiler understands __attribute__ */
-#undef HAVE_ATTRIBUTE
+#undef HAVE_GCC_ATTRIBUTE
+
+/* Define if the compiler understands __FUNCTION__ */
+#undef HAVE_GCC_FUNCTION
 
 /* Define if a we have working UNIX98 pty handling */
 #undef HAVE_UNIX98_PTYS
@@ -59,3 +65,7 @@
 
 /* Define to support non-standard packets of ssh2 */
 #undef DATAFELLOWS_WORKAROUNDS
+
+/* Global variables needed by argp */
+#undef HAVE_PROGRAM_INVOCATION_NAME
+#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
