@@ -2,7 +2,7 @@
  *
  * Information about ssh channels.
  *
- * $Id: channel.h,v 1.45 1999/10/02 19:52:39 nisse Exp $
+ * $Id: channel.h,v 1.46 1999/10/11 20:34:40 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -338,7 +338,8 @@ make_channel_read_close_callback(struct ssh_channel *channel);
 struct exception_handler *
 make_channel_io_exception_handler(struct ssh_channel *channel,
 				  const char *prefix,
-				  struct exception_handler *parent);
+				  struct exception_handler *parent,
+				  const char *context);
 
 struct lsh_string *channel_transmit_data(struct ssh_channel *channel,
 					 struct lsh_string *data);
