@@ -1,6 +1,6 @@
 /* client_keyexchange.c
  *
- * $Id: client_keyexchange.c,v 1.32 1999/09/06 22:13:49 nisse Exp $ */
+ * $Id: client_keyexchange.c,v 1.33 1999/10/02 20:00:28 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -136,7 +136,7 @@ do_handle_dh_reply(struct packet_handler *c,
 #if DATAFELLOWS_WORKAROUNDS
   if (! (connection->peer_flags & PEER_SEND_NO_DEBUG))
 #endif
-    send_verbose(connection, "Key exchange successful!", 0);
+    send_verbose(connection->write, "Key exchange successful!", 0);
   
   if (connection->established)
     {
