@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.13 1999/09/07 16:46:48 nisse Exp $
+ * $Id: connection_commands.c,v 1.14 1999/10/11 21:00:48 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -355,7 +355,7 @@ do_connection(struct command *s,
 		    make_connection_close_handler(connection))
      ->write_buffer->super,
      self->random,
-     make_exc_finish_read_handler(&fd->super, e));
+     make_exc_finish_read_handler(&fd->super, e, HANDLER_CONTEXT));
 
   connection->versions[self->mode] = version;
   connection->kexinits[self->mode] = MAKE_KEXINIT(self->init); 
