@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.45 1999/09/20 22:02:31 nisse Exp $ */
+ * $Id: io.h,v 1.46 1999/10/11 20:57:53 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -326,7 +326,8 @@ struct io_fd *make_io_fd(struct io_backend *b,
 
 struct exception_handler *
 make_exc_finish_read_handler(struct lsh_fd *fd,
-			     struct exception_handler *parent);
+			     struct exception_handler *parent,
+			     const char *context);
 
 struct connect_fd *
 io_connect(struct io_backend *b,
