@@ -1,6 +1,6 @@
 /* queue.h
  *
- * $Id: queue.h,v 1.6 1999/06/14 01:34:30 nisse Exp $
+ * $Id: queue.h,v 1.7 1999/10/02 18:28:13 nisse Exp $
  *
  * Generic doubly linked list. */
 
@@ -28,7 +28,6 @@
 
 #include "lsh.h"
 
-#include "list.h"
 
 /* Layout taken from AmigaOS lists... The first node uses a prev
  * pointer that points to the queue's HEAD. The last node uses a next
@@ -87,7 +86,7 @@ struct object_queue_node
      (name object_queue)
      (vars
        (length . UINT32)
-       (q special-struct "struct lsh_queue"
+       (q indirect-special "struct lsh_queue"
           do_object_queue_mark do_object_queue_free)))
 */
 
