@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.c,v 1.15 1999/09/07 09:05:22 nisse Exp $ */
+ * $Id: sexp.c,v 1.18 1999/10/13 16:03:06 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -716,5 +716,97 @@ int sexp_get_un(struct sexp_iterator *i, const char *name, mpz_t n)
   return 1;
 }
 
-  
-  
+
+/* Command line options */
+struct sexp_format
+{
+  char *name;
+  int id;
+};
+
+static const struct sexp_format sexp_formats[] = {
+  { "transport", SEXP_TRANSPORT },
+  { "canonical", SEXP_CANONICAL },
+  { "advanced", SEXP_ADVANCED },
+  { "international", SEXP_INTERNATIONAL },
+  { NULL, 0 }
+};
+
+#if 0
+static void list_formats(void)
+{
+  int i;
+
+  werror("Available formats are:\n");
+  for (i = 0; sexp_formats[i].name; i++)
+    werror("  %z\n", sexp_formats[i].name);
+}
+#endif
+
+static int lookup_sexp_format(const char *name)
+{
+  int i;
+
+  for (i = 0; sexp_formats[i].name; i++)
+    {
+      if (strcmp(sexp_formats[i].name, name) == 0)
+	return sexp_formats[i].id;
+    }
+  return -1;
+}
+
+static const struct argp_option
+sexp_input_options[] =
+{
+  { NULL, 0, NULL, 0, "Valid sexp-formats are transport, canonical, "
+    "advanced and international.", 0 },
+  { "input-format", 'i', "format", 0,
+    "Variant of the s-expression syntax to accept.", 0},
+  { NULL, 0, NULL, 0, NULL, 0 }
+};
+
+static const struct argp_option
+sexp_output_options[] =
+{
+  { NULL, 0, NULL, 0, "Valid sexp-formats are transport, canonical, "
+    "advanced and international.", 0 },
+  { "output-format", 'o', "format", 0,
+    "Variant of the s-expression syntax to generate.", 0},
+  { NULL, 0, NULL, 0, NULL, 0 }
+};
+
+static error_t
+sexp_argp_parser(int key, char *arg, struct argp_state *state)
+{
+  switch(key)
+    {
+    default:
+      return ARGP_ERR_UNKNOWN;
+    case 'o':
+    case 'i':
+      {
+	int format = lookup_sexp_format(arg);
+	if (format < 0)
+	  argp_error(state, "Unknown s-expression format '%s'", arg);
+	else
+	  *(sexp_argp_state *) (state->input) = format;
+
+	break;
+      }
+    }
+  return 0;
+}
+
+const struct argp sexp_input_argp =
+{
+  sexp_input_options,
+  sexp_argp_parser,
+  NULL, NULL, NULL, NULL, NULL
+};
+
+const struct argp sexp_output_argp =
+{
+  sexp_output_options,
+  sexp_argp_parser,
+  NULL, NULL, NULL, NULL, NULL
+};
